package com.jiuqi.sql;

import java.util.Date;

public abstract class OutputDataSet {
   private boolean active;
   private FieldInfoList fieldInfos = new FieldInfoList();
   private OutputRecordBuffer buffer;

   private FieldInfo findField(String fieldName) throws DBException {
      int index = this.fieldInfos.find(fieldName);
      if (index < 0) {
         throw new DBException(fieldName + " Not Exists");
      } else {
         FieldInfo result = this.fieldInfos.get(index);
         return result;
      }
   }

   public FieldInfo addField(String name, int type) {
      FieldInfo fieldInfo = this.fieldInfos.add();
      fieldInfo.name = name;
      fieldInfo.type = type;
      switch (type) {
         case 1:
            fieldInfo.size = 1;
            break;
         case 2:
            fieldInfo.size = 8;
            break;
         case 3:
            fieldInfo.size = 8;
         case 4:
         case 6:
         case 7:
         default:
            break;
         case 5:
            fieldInfo.size = 4;
            break;
         case 8:
            fieldInfo.size = 8;
      }

      return fieldInfo;
   }

   public void addField(String name, int type, int size) {
      FieldInfo fieldInfo = this.fieldInfos.add();
      fieldInfo.name = name;
      fieldInfo.type = type;
      fieldInfo.size = size;
   }

   public FieldInfoList getFields() {
      return this.fieldInfos;
   }

   public abstract byte[] getBytes();

   protected abstract void postRecord(OutputRecordBuffer var1) throws DBException;

   protected abstract void internalCreate(FieldInfoList var1) throws DBException;

   protected abstract OutputRecordBuffer internalOpen() throws DBException;

   protected abstract void internalClose() throws DBException;

   public void createTable() throws DBException {
      this.internalCreate(this.fieldInfos);
   }

   public void open() throws DBException {
      if (!this.active) {
         this.buffer = this.internalOpen();
         this.fieldInfos.refreshFinder();
         this.active = true;
      }
   }

   public void append() throws DBException {
      this.buffer.clearBuffer();
   }

   public void post() throws DBException {
      this.postRecord(this.buffer);
   }

   public boolean isActive() {
      return this.active;
   }

   public void close() throws DBException {
      if (this.active) {
         this.internalClose();
         this.active = false;
      }
   }

   public int fieldIndexOf(String fieldName) {
      return this.fieldInfos.find(fieldName);
   }

   public void setBoolean(int index, boolean value) throws DBException {
      this.buffer.writeBoolean(this.fieldInfos.get(index - 1), value);
   }

   public void setBoolean(String fieldName, boolean value) throws DBException {
      this.buffer.writeBoolean(this.findField(fieldName), value);
   }

   public void setInt(int index, int value) throws DBException {
      this.buffer.writeInt(this.fieldInfos.get(index - 1), value);
   }

   public void setInt(String fieldName, int value) throws DBException {
      this.buffer.writeInt(this.findField(fieldName), value);
   }

   public void setLong(int index, long value) throws DBException {
      this.buffer.writeLong(this.fieldInfos.get(index - 1), value);
   }

   public void setLong(String fieldName, long value) throws DBException {
      this.buffer.writeLong(this.findField(fieldName), value);
   }

   public void setString(int index, String value) throws DBException {
      this.buffer.writeString(this.fieldInfos.get(index - 1), value);
   }

   public void setString(String fieldName, String value) throws DBException {
      this.buffer.writeString(this.findField(fieldName), value);
   }

   public void setDouble(int index, double value) throws DBException {
      this.buffer.writeDouble(this.fieldInfos.get(index - 1), value);
   }

   public void setDouble(String fieldName, double value) throws DBException {
      this.buffer.writeDouble(this.findField(fieldName), value);
   }

   public void setDate(int index, Date value) throws DBException {
      this.buffer.writeDate(this.fieldInfos.get(index - 1), value);
   }

   public void setDate(String fieldName, Date value) throws DBException {
      this.buffer.writeDate(this.findField(fieldName), value);
   }

   public void setNull(int index) throws DBException {
      this.buffer.writeNull(this.fieldInfos.get(index - 1));
   }

   public void setNull(String fieldName) throws DBException {
      this.buffer.writeNull(this.findField(fieldName));
   }
}
